==> vlc-1.2.0-pre1.tar.xz: vlc-1.2.0-pre1/modules/stream_filter/dash/mpd/BasicCMManager.h <==
/*
 * BasicCMManager.h
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef BASICCMMANAGER_H_
#define BASICCMMANAGER_H_

#include <iostream>
#include <stdio.h>
#include <stdlib.h>

#include "mpd/MPD.h"
#include "mpd/Period.h"
#include "mpd/Group.h"
#include "mpd/Representation.h"
#include "mpd/SegmentInfo.h"
#include "mpd/InitSegment.h"
#include "mpd/Segment.h"
#include "mpd/ISegment.h"
#include "mpd/IMPDManager.h"
#include "exceptions/AttributeNotPresentException.h"
#include "exceptions/ElementNotPresentException.h"

namespace dash
{
    namespace mpd
    {
        class BasicCMManager : public IMPDManager
        {
            public:
                BasicCMManager          (MPD *mpd);
                virtual ~BasicCMManager ();

                std::vector<Period *>   getPeriods              ();
                Period*                 getFirstPeriod          ();
                Period*                 getNextPeriod           (Period *period);
                Representation*         getBestRepresentation   (Period *period);
                std::vector<ISegment *> getSegments             (Representation *rep);
                Representation*         getRepresentation       (Period *period, long bitrate);

            private:
                MPD *mpd;
        };
    }
}

#endif /* BASICCMMANAGER_H_ */

==> vlc-2.0.3.tar.xz: vlc-2.0.3/modules/stream_filter/dash/mpd/BasicCMManager.h <==
/*
 * BasicCMManager.h
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef BASICCMMANAGER_H_
#define BASICCMMANAGER_H_

#include <iostream>
#include <stdio.h>
#include <stdlib.h>

#include "mpd/MPD.h"
#include "mpd/Period.h"
#include "mpd/Group.h"
#include "mpd/Representation.h"
#include "mpd/SegmentInfo.h"
#include "mpd/Segment.h"
#include "mpd/IMPDManager.h"

namespace dash
{
    namespace mpd
    {
        class BasicCMManager : public IMPDManager
        {
            public:
                BasicCMManager          (MPD *mpd);
                virtual ~BasicCMManager ();

                const std::vector<Period *>&    getPeriods() const;
                Period*                         getFirstPeriod();
                Period*                         getNextPeriod( Period *period );
                Representation*                 getBestRepresentation( Period *period );
                std::vector<Segment *>          getSegments( Representation *rep );
                Representation*                 getRepresentation( Period *period, int bitrate );
                const MPD*                      getMPD() const;

            private:
                MPD *mpd;
        };
    }
}

#endif /* BASICCMMANAGER_H_ */
